@@ -1,74 +1,57 @@
 ;; Author: Leslie Harlley Watter
 
+
+;; HOWTO INSTALL
+
+;;
+;; PT_BR  ( english users look below :D )
+;;
+
+
+;; 1) Crie/Copie este arquivo (txt2tags-mode.el) para o diretrio ~/emacs/txt2tags/.
+;; 2) Insira o seguinte cdigo no final do seu ~/.emacs
+;; ------
+;; (add-to-list 'load-path "~/projetos/txt2tags/2.x/")
+;; (setq auto-mode-alist (append (list
+;; 	'("\\.t2t$" . t2t-mode)
+;; 	)
+;; 	(if (boundp 'auto-mode-alist) auto-mode-alist)
+;; ))
+;; (autoload  't2t-mode "txt2tags-mode" "Txt2tags Mode" t)
+;; -----
+;; E pronto, basta fechar e abrir novamente o emacs que ele ir carregar o txt2tags-mode automaticamente quando
+;; um arquivo .t2t for aberto ;-)
+
+
+
+;;
+;; EN_US
+;;
+
+;; To install txt2tags-mode you just need to do a few steps:
+;; 1) Copy this archieve (txt2tags-mode.el) to your ~/emacs/txt2tags directory. 
+;; (If you don't have such a directory, you can create one just to organize your things)
+;; 2) Add the following code to the end of your ~/.emacs
+;; ------
+;; (add-to-list 'load-path "~/projetos/txt2tags/2.x/")
+;; (setq auto-mode-alist (append (list
+;; 	'("\\.t2t$" . t2t-mode)
+;; 	)
+;; 	(if (boundp 'auto-mode-alist) auto-mode-alist)
+;; ))
+;; (autoload  't2t-mode "txt2tags-mode" "Txt2tags Mode" t)
+;; -----
+;; That's all. Close your emacs and reopen it. Emacs will parse and fontify all of .t2t files ;-)
+
+
+
+
 ;; TODO
 
-;; Internacionalizar o menu
 ;; Ajustar as regexps de tabelas
 ;; Ajustar a regexp da data para pegar %%date(%c) e variantes
+;; rewrite the entire documentation.
 
-;; Criar uma fonte para cada TAG, mais fcil de gerenciar.
-
-
-;; NOTA
-
-;; As listas esto casando legal com tudo ver o porque 
-;; acho que  o \\b
-
-
-;; Changelog
-
-;; 20/10/2004
-
-;; Adicionando menus
-;; Thanks to edrx, bpalmer, forcer and e1f at #emacs
-
-;; 21/07/2004
-
-;; Inserindo fonte para mostrar os trailing spaces ao final das linhas
-;; Inserindo varivel local tambm para j comear mostrando.
-;; Pedido do Guaracy.
-
-;; 19/07/2004
-
-;; Melhorando as regexps de links 
-;; Agora as regies de ``` tambm so marcadas
-
-;; 12/07/2004
-
-;; Adicionando a fonte raw para a marcao --- oneliner em um nvel mais superior
-
-;; M-x compile agora tem a opo de target padro. Coloquei o html, 
-;; mas  uma varivel que pode ser mudada com o M-x customize-group t2t
-
-;; As listas agora voltam a funcionar - + : so identificadas.
-;; o problema estava na cor que eu atribua s listas (blah).
-
-;; Sees numeradas agora sem ancoras tambm
-
-
-;; 10/07/2004
-
-;; Comando de "compilar" modificado.
-;; Agora quando precisar compilar o documento t2t aberto,  s executar 
-;; M-x compile
-
-;; Criadas as fontes section-{1,2,3,4,5}. Valeu Guaracy.
-
-;;  8/07/2004
-;;  Inserido o :group 'txt2tags-faces no final da definio das fontes. Isso permite 
-;;  que o M-x customize-group txt2tags possa definir as fontes do usurio sobrepondo a minha 
-;;  definio. Obrigado  sachac #emacs
-
-;; 3/10/2003
-;; Hoje eu consegui arrumar um problema com a regexp do negrito
-;; uma aspa faltando antes do nome da fonte tava dando erro
-;; a regesp do negrito tava errada
-
-;; http://two-wugs.net/emacs/mode-tutorial.html#fontlock
-
-;; Here, we define some variables that all modes should define. 
-;; t2t-mode-hook allows the user to run their own code when your mode is run.
-;; t2t-mode-map allows users to define their own keymaps.
 
 (defvar t2t-mode-hook nil)
 (defvar t2t-mode-map nil
@@ -91,7 +74,7 @@
    ((file-exists-p "/usr/local/bin/txt2tags") "/usr/local/bin/txt2tags")
    ((file-exists-p "/usr/bin/txt2tags") "/usr/bin/txt2tags")
    ((file-exists-p "/bin/txt2tags") "/bin/txt2tags")
-   ;;   ((file-exists-p "/home/leslie/bin/bin/txt2tags") "/home/leslie/bin/bin/txt2tags")
+;;   ((file-exists-p "/home/leslie/bin/bin/txt2tags") "/home/leslie/bin/bin/txt2tags")
    ((file-exists-p "~/projetos/txt2tags/programa/txt2tags") "~/projetos/txt2tags/programa/txt2tags")
    ( t "txt2tags")
    )
@@ -192,7 +175,7 @@
 
 ;; negrito + itlico
 (defface t2t-bold-italic-face '((t (:width extra-expanded :weight extra-bold :slant italic
-										   :underline nil :foreground "medium slate blue" :background "black"))) 
+			    :underline nil :foreground "medium slate blue" :background "black"))) 
   "Txt2Tags Bold Italic." :group 'txt2tags-faces)
 
 
@@ -224,15 +207,13 @@
 	   auto-mode-alist))
 
 
+;; self comment
 ;;; Ateno !!! IMPORTANTE !!
 ;; NAO esquecer a aspa simples antes do nome da fonte   '("^%%.*" . --->'<----t2t-comments-face)
 ;; seno tem que declarar uma varivel com o mesmo nome da fonte
 ;; Veja o comentrio ao final deste modo
 
 
-;; nas regexps de negrito, tive que colocar dois ** para casar com um * mesmo dentro da lista
-;; xunxera do caramba, mas funcionou.
-
 
 (defconst t2t-font-lock-keywords-0
   (list
@@ -258,43 +239,43 @@
 
 (defconst t2t-font-lock-keywords-1
   (append t2t-font-lock-keywords-0
-		  (list
-		   ;; Data - Date
-		   '("%%date\\((%[mMdDyY][-/: ]%[mMdDyY][-/: ]%[mMdDyY])\\)?" . 't2t-date-face)
-		   '("%%date\\((%[mMdDyY][-/: ]%[mMdDyY])\\)" . 't2t-date-face)
-		   '("%%date[()%aAbBcdHImMdpSxXyY]+?" . 't2t-date-face)
-		   ;; rea de Configurao - Configuration area
-		   ;; casa %!target 
-		   '("%![-\"\<\>\'\{\}\\=;/.,:?_() A-Za-z--0-9]+" . 't2t-config-face)
-		   ;; Postproc Area %%!postproc
-		   '("%%!postproc[-\"\<\>\'\{\}\\=;/.,:?_() A-Za-z--0-9]+" . 't2t-postproc-face)
-		   ;; Comentrios - Comments
-		   '("^%.*" . 't2t-comments-face)
-		   ;; Ttulos de Sees no numerados - Unnumbered Section titles 
-		   '("=====[-/.,:?_() A-Za-z--0-9\+=]+?=====$" . 't2t-sections-face-5) 
-		   '("====[-/.,:?_() A-Za-z--0-9\+=]+?====$" . 't2t-sections-face-4) 
-		   '("===[-/.,:?_() A-Za-z--0-9\+=]+?===$" . 't2t-sections-face-3) 
-		   '("==[-/.,:?_() A-Za-z--0-9\+=]+?==$" . 't2t-sections-face-2) 
-		   '("=[-/.,:?_() A-Za-z--0-9\+]+?=$" . 't2t-sections-face-1) 
-		   ;; Ttulos de Sees no numerados com ncora - Unnumbered Section titles with anchors
-		   '("=====[-/.,:?_() A-Za-z--0-9\+=]+?=====\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-5) 
-		   '("====[-/.,:?_() A-Za-z--0-9\+=]+?====\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-4) 
-		   '("===[-/.,:?_() A-Za-z--0-9\+=]+?===\[[-_A-Za-z--0-9\]+\]?$" . 't2t-sections-face-3) 
-		   '("==[-/.,:?_() A-Za-z--0-9\+=]+?==\[[-_A-Za-z--0-9\]+\]?$" . 't2t-sections-face-2) 
-		   '("=[-/.,:?_() A-Za-z--0-9]+?=\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-1) 
-		   ;; Ttulos de Sees numerados - Numbered Section titles 
-		   '("\\+\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\\+$" . 't2t-sections-face-5) 
-		   '("\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+$" . 't2t-sections-face-4) 
-		   '("\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+$" . 't2t-sections-face-3) 
-		   '("\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+$" . 't2t-sections-face-2) 
-		   '("\\+[-/.,:?_() A-Za-z--0-9=]+?\\+$" . 't2t-sections-face-1) 
-		   ;; Ttulos de Sees numerados com ncora- Numbered Section titles with anchors
-		   '("\\+\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-5) 
-		   '("\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-4) 
-		   '("\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-3) 
-		   '("\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-2) 
-		   '("\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-1) 
-		   ))
+  (list
+   ;; Data - Date
+   '("%%date\\((%[mMdDyY][-/: ]%[mMdDyY][-/: ]%[mMdDyY])\\)?" . 't2t-date-face)
+   '("%%date\\((%[mMdDyY][-/: ]%[mMdDyY])\\)" . 't2t-date-face)
+   '("%%date[()%aAbBcdHImMdpSxXyY]+?" . 't2t-date-face)
+   ;; rea de Configurao - Configuration area
+   ;; casa %!target 
+   '("%![-\"\<\>\'\{\}\\=;/.,:?_() A-Za-z--0-9]+" . 't2t-config-face)
+   ;; Postproc Area %%!postproc
+   '("%%!postproc[-\"\<\>\'\{\}\\=;/.,:?_() A-Za-z--0-9]+" . 't2t-postproc-face)
+   ;; Comentrios - Comments
+   '("^%.*" . 't2t-comments-face)
+   ;; Ttulos de Sees no numerados - Unnumbered Section titles 
+   '("=====[-/.,:?_() A-Za-z--0-9\+=]+?=====$" . 't2t-sections-face-5) 
+   '("====[-/.,:?_() A-Za-z--0-9\+=]+?====$" . 't2t-sections-face-4) 
+   '("===[-/.,:?_() A-Za-z--0-9\+=]+?===$" . 't2t-sections-face-3) 
+   '("==[-/.,:?_() A-Za-z--0-9\+=]+?==$" . 't2t-sections-face-2) 
+   '("=[-/.,:?_() A-Za-z--0-9\+]+?=$" . 't2t-sections-face-1) 
+   ;; Ttulos de Sees no numerados com ncora - Unnumbered Section titles with anchors
+   '("=====[-/.,:?_() A-Za-z--0-9\+=]+?=====\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-5) 
+   '("====[-/.,:?_() A-Za-z--0-9\+=]+?====\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-4) 
+   '("===[-/.,:?_() A-Za-z--0-9\+=]+?===\[[-_A-Za-z--0-9\]+\]?$" . 't2t-sections-face-3) 
+   '("==[-/.,:?_() A-Za-z--0-9\+=]+?==\[[-_A-Za-z--0-9\]+\]?$" . 't2t-sections-face-2) 
+   '("=[-/.,:?_() A-Za-z--0-9]+?=\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-1) 
+   ;; Ttulos de Sees numerados - Numbered Section titles 
+   '("\\+\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\\+$" . 't2t-sections-face-5) 
+   '("\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+$" . 't2t-sections-face-4) 
+   '("\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+$" . 't2t-sections-face-3) 
+   '("\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+$" . 't2t-sections-face-2) 
+   '("\\+[-/.,:?_() A-Za-z--0-9=]+?\\+$" . 't2t-sections-face-1) 
+   ;; Ttulos de Sees numerados com ncora- Numbered Section titles with anchors
+   '("\\+\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-5) 
+   '("\\+\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-4) 
+   '("\\+\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-3) 
+   '("\\+\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-2) 
+   '("\\+[-/.,:?_() A-Za-z--0-9=]+?\\+\[[-_A-Za-z--0-9]+\]?$" . 't2t-sections-face-1) 
+   ))
   "Minimal highlighting expressions for T2T mode")
 
 
@@ -322,38 +303,38 @@
 
 (defconst t2t-font-lock-keywords-3
   (append t2t-font-lock-keywords-2
-		  (list
-		   ;; Tabela - Tables
-		   ;; linha de titulo de tabela COM e SEM os pipes
-		   ;; table title line  WITH and WITHOUT pipes
-		   '("^ ?||\\( |\\| \\|\t\\|\\sw\\|[A-Za-z--0-9]\\)+" . 't2t-tables-face)
-		   ;; corpo da tabela - table body
-		   '("^|\\(\\(\\s.\\|\\sw\\| \\|[A-Za-z--0-9]\\)+\\( |\\)+\\)+" . 't2t-tables-face)
-		   ;; corpo da tabela sem pipes - table body without pipes
-		   ;;	   '("^|\\(\\(\\( \\|\t\\)\\(\\s.\\|\\sw\\| \\|[--0-9]\\)+\\)\\)+" . 't2t-tables-face)
-		   ;; Listas -- (ainda nao vi como fazer com regioes inteiras)
-		   ;; Lists
-		   '("^[ \t]+- \\b" . 't2t-lists-face )
-		   ;; definition list
-		   '("^[ \t]*: \\b" . 't2t-lists-face )
-		   ;; listas numeradas
-		   '("^[ \t]*\\+ \\b" . 't2t-lists-face )
-		   ;; numeros com cor tambm
-		   '(" -?[0-9.]+" . 't2t-numbers-face)
-		   )
-		  )
+	  (list
+	   ;; Tabela - Tables
+	   ;; linha de titulo de tabela COM e SEM os pipes
+	   ;; table title line  WITH and WITHOUT pipes
+	   '("^ ?||\\( |\\| \\|\t\\|\\sw\\|[A-Za-z--0-9]\\)+" . 't2t-tables-face)
+	   ;; corpo da tabela - table body
+	   '("^|\\(\\(\\s.\\|\\sw\\| \\|[A-Za-z--0-9]\\)+\\( |\\)+\\)+" . 't2t-tables-face)
+	   ;; corpo da tabela sem pipes - table body without pipes
+;;	   '("^|\\(\\(\\( \\|\t\\)\\(\\s.\\|\\sw\\| \\|[--0-9]\\)+\\)\\)+" . 't2t-tables-face)
+	   ;; Listas -- (ainda nao vi como fazer com regioes inteiras)
+	   ;; Lists
+	   '("^[ \t]+- \\b" . 't2t-lists-face )
+	   ;; definition list
+	   '("^[ \t]*: \\b" . 't2t-lists-face )
+	   ;; listas numeradas
+	   '("^[ \t]*\\+ \\b" . 't2t-lists-face )
+	   ;; numeros com cor tambm
+	   '(" -?[0-9.]+" . 't2t-numbers-face)
+	   )
+	  )
   "Complete highlighting in T2T mode")
 
 
 (defconst t2t-font-lock-keywords-4
   (append t2t-font-lock-keywords-3
-		  (list
-		   ;; regies !!
-		   '(txt2tags-region-lock-matcher
-			 (0 't2t-region-face) 
-			 (1 't2t-region-face))
-		   )
-		  )
+	  (list
+	   ;; regies !!
+	   '(txt2tags-region-lock-matcher
+	     (0 't2t-region-face) 
+	     (1 't2t-region-face))
+	   )
+	  )
   "Regions highlighting in T2T mode")
 
 
@@ -371,17 +352,17 @@
 
 ;;  Original idea from font-latex-match-math-env command in font-latex.el.
 ;; retirado do emacs-wiki. Enquanto eu no tiver mais conhecimentos de lisp, fica como est
-(defun txt2tags-region-lock-matcher (limit)
-  "
+ (defun txt2tags-region-lock-matcher (limit)
+   "
  ```
  This region will be highlighted
  ```
  " 
   ;; search for the begin of the first region
   (when (re-search-forward "^```$" limit t)
-    (let ((beg (match-end 0)) end		; 1st Region
-		  beg2 end2						; 2nd Region
-		  ) 
+    (let ((beg (match-end 0)) end ; 1st Region
+		  beg2 end2 ; 2nd Region
+		) 
 	  ;; search for end of region 1 and start of region 2
       (if (re-search-forward "^```$" limit t)
 		  (progn
@@ -407,10 +388,28 @@
   (if t2t-mode-syntax-table
       ()
     (setq t2t-mode-syntax-table (make-syntax-table))
+	
+	;; The first modification we make to the syntax table is to declare the 
+	;; underscore character '_' as being a valid part of a word. 
+	;; So now, a string like foo_bar will be treated as one word rather than two 
+	;; (the default Emacs behavior). 
+	
 	(modify-syntax-entry ?_ "w" t2t-mode-syntax-table))
+
+	;; %% inicia comentrio 
+;; 	(modify-syntax-entry ?/ ". 124b" t2t-mode-syntax-table)
+;; 	(modify-syntax-entry ?* ". 23" t2t-mode-syntax-table)
+;; 	(modify-syntax-entry ?\n "> b" t2t-mode-syntax-table))
   
   (set-syntax-table t2t-mode-syntax-table))
 
+
+;; Here we define our entry function, give it a documentation string, make it interactive,
+;;  and call our syntax table creation function.
+
+
+
+
 ;; menu
 
 ;; Nota:  NECESSARIO TER O t2t-mode-map definido como no nil para que funcione o menu
@@ -440,9 +439,13 @@
   (define-key t2t-mode-map [(control ?c) (control ?i)]              't2t-insert-image)
   (define-key t2t-mode-map [(control ?c) (control ?d)]              't2t-insert-date)
   (define-key t2t-mode-map [(control ?c) (control ?c)]              't2t-insert-comments)
-  )
+)
 
 
+;; esse if  responsvel por verificar a linguagem do sistema
+
+(if (string= (getenv "LANG") "pt_BR")
+;; ok, the user is using pt_BR language
 (easy-menu-define t2t-mode-menu t2t-mode-map
   "'Txt2Tags-mode' menu"
   '("T2T"
@@ -492,6 +495,59 @@
     ;;     (progn (save-excursion (goto-char (mark)) (beginning-of-line) (insert ?% " ")))
     )
   )
+;; other language; try english as default
+(easy-menu-define t2t-mode-menu t2t-mode-map
+  "'Txt2Tags-mode' menu"
+  '("T2T"
+    ("Title" 
+     ["Ununmbered"       (t2t-insert-normal-title)      :keys "C-c C-t C-t"]
+     ["Numbered"     (t2t-insert-numbered-title)    :keys "C-c C-t C-n"]
+     )
+    ("Font Beautifiers"
+     ["Bold"      (t2t-insert-bold-face)         :keys "C-c C-f C-b"]
+     ["Italic"      (t2t-insert-italic-face)       :keys "C-c C-f C-i"]
+
+     ["Underline"   (t2t-insert-underlined-face)   :keys "C-c C-f C-u"]
+     ["Monospaced" (t2t-insert-monospace-face)    :keys "C-c C-f C-m"]
+     ;; (progn (save-excursion (goto-char (mark)) (insert "''")) (insert "''"))
+     )
+    ("Text Blocks"
+     ["Citation"             (t2t-insert-citation)        :keys "C-c C-b C-c"]
+     ["List"               (t2t-insert-unumbered-list)  :keys "C-c C-b C-l"]
+     ["Numbered List"      (t2t-insert-numbered-list)   :keys "C-c C-b C-n"]
+     ["Definition List"  (t2t-insert-definition-list) :keys "C-c C-b C-d"]
+     )
+    ("Verbatim"
+     ["Verbatim Line"     (t2t-insert-formated-line)   :keys "C-c C-f C-l"]
+     ["Verbatim Area"      (t2t-insert-formated-area)   :keys "C-c C-f C-a"]
+     )
+    ("RAW"
+     ["Raw line"     (t2t-insert-protected-line) :keys "C-c C-p C-l"]
+     ;; (progn (save-excursion (goto-char (mark)) (beginning-of-line)) (insert "\n\"\"\" ")) 
+     ["Raw area"      (t2t-insert-protected-area) :keys "C-c C-p C-a"]
+     ;; (progn (save-excursion (goto-char (mark)) (insert "\n\"\"\"\n")) (insert "\n\"\"\"\n")) 
+     ["RAW Text"     (t2t-insert-protected-text) :keys "C-c C-p C-t"]
+     ;; (progn (save-excursion (goto-char (mark)) (insert "\"\"")) (insert "\"\"")) 
+     ;;      ["Tabela" 
+     ;;       () t]
+     )
+    ("Others"
+     ["Horizontal Separator Line"   (t2t-insert-separation-line) :keys "C-c C-o C-s"]
+     ;; (progn (save-excursion (goto-char (mark)) (beginning-of-line)) (insert "\n----------------------")) 
+     ["Horizontal Bold Line"      (t2t-insert-emphasize-line)  :keys "C-c C-o C-d"]
+     ;; (progn (save-excursion (goto-char (mark)) (beginning-of-line)) (insert "\n======================"))
+     )
+    ("--")
+	["Links"              (t2t-insert-link)            :keys "C-c C-l"]
+	["Image"              (t2t-insert-image)           :keys "C-c C-i"]
+	["Date"               (t2t-insert-date)            :keys "C-c C-d"]
+    ["Comments"           (t2t-insert-comments)        :keys "C-c C-c"]
+    ;;     (progn (save-excursion (goto-char (mark)) (beginning-of-line) (insert ?% " ")))
+    )
+  )
+
+) ;; ends if language   
+
 
 
 
@@ -500,7 +556,7 @@
 (defun t2t-insert-normal-title ()
   (interactive)
   (save-excursion (goto-char (point)) (beginning-of-line)
-				  (insert "\n= "))
+		  (insert "\n= "))
   (end-of-line)
   (insert " ="))
 
@@ -508,7 +564,7 @@
 (defun t2t-insert-numbered-title ()
   (interactive)
   (save-excursion (goto-char (point)) (beginning-of-line)
-				  (insert "\n+ "))
+		  (insert "\n+ "))
   (end-of-line)
   (insert " +"))
 
@@ -517,27 +573,27 @@
 (defun t2t-insert-bold-face ()
   (interactive)
   (save-excursion (goto-char (region-beginning))
-				  (insert "**"))
+		  (insert "**"))
   (insert "**"))
 
 
 (defun t2t-insert-italic-face ()
   (interactive)
   (save-excursion (goto-char (region-beginning))
-				  (insert "//"))
+		  (insert "//"))
   (insert "//"))
 
 
 (defun t2t-insert-underlined-face ()
   (interactive)
   (save-excursion (goto-char (region-beginning))
-				  (insert "__"))
+		  (insert "__"))
   (insert "__"))
 
 (defun t2t-insert-monospace-face ()
   (interactive)
   (save-excursion (goto-char (region-beginning))
-				  (insert "''"))
+		  (insert "''"))
   (insert "''"))
 
 ;; lists
@@ -546,13 +602,13 @@
   (interactive)
   (setq citat (read-string "Texto: "))
   (unless (equal citat "")
-	(insert (format "\n\t" citat ))))
+  (insert (format "\n\t" citat ))))
 
 (defun t2t-insert-definition-list ()
   (interactive)
   (setq descr (read-string "Item: "))
   (unless (equal descr "")
-	(insert (format "\n : %s \n" descr ))))
+  (insert (format "\n : %s \n" descr ))))
 
 
 (defun t2t-insert-unumbered-list ()
@@ -620,7 +676,7 @@
   (unless (equal linkname "")
     (setq urllink (read-string "Link: "))
     (unless (equal urllink "")
-	  (insert (format "[%s %s]" linkname urllink)))))
+    (insert (format "[%s %s]" linkname urllink)))))
 
 (defun t2t-insert-image ()
   (interactive)
@@ -637,7 +693,7 @@
 (defun t2t-insert-comments ()
   (interactive)
   (save-excursion (goto-char (point)) (beginning-of-line) (insert ?% " ")))
-                   
+
 (defun t2t-mode ()
   "Major mode for editing Txt2Tags files"
   (interactive)
@@ -647,25 +703,29 @@
   (setq font-lock-defaults
 		'(t2t-font-lock-keywords))
 
-  (add-hook 't2t-mode-hook
-			(lambda ()
-			  (set (make-local-variable 'show-trailing-whitespace)
-				   t )))
+;; faz com que o final de linha seja mostrado em vermelho
 
   (add-hook 't2t-mode-hook
-			(lambda ()
-			  (set (make-local-variable 'compile-command)
-				   (let ((file (file-name-nondirectory buffer-file-name)))
-					 (concat t2t-program " -t " t2t-default-target " " file)))))
+	    (lambda ()
+	      (set (make-local-variable 'show-trailing-whitespace)
+			   t )))
+
+;; Muda a varivel compile-command para txt2tags arquivo.t2t
+  (add-hook 't2t-mode-hook
+	    (lambda ()
+	      (set (make-local-variable 'compile-command)
+		   (let ((file (file-name-nondirectory buffer-file-name)))
+		     (concat t2t-program " -t " t2t-default-target " " file)))))
   
-  ;; Ativa por padro o syntax higlight
+;; Ativa por padro o syntax higlight
   (add-hook 't2t-mode-hook 'turn-on-font-lock)
-  ;; ativa o mapa e menu
+;; ativa o mapa e menu
   (use-local-map t2t-mode-map)
   (easy-menu-add t2t-mode-menu)
-  ;; major-mode
+;; major-mode
   (setq major-mode 't2t-mode)
   (setq mode-name "T2T")
   (run-hooks 't2t-mode-hook))
 
 (provide 't2t-mode)
+
