@@ -19,9 +19,10 @@ headers = ['Header 1', 'Header 2', 'Header 3']
 
 # Set the configuration on the 'config' dict.
 config = txt2tags.ConfigMaster()._get_defaults()
-config['target'] = 'html'            # target type: HTML
-config['encoding'] = 'iso-8859-1'    # document encoding
-config['css-sugar'] = 1              # CSS flag
+config['outfile'] = txt2tags.MODULEOUT  # results as list
+config['target'] = 'html'               # target type: HTML
+config['encoding'] = 'iso-8859-1'       # document encoding
+config['css-sugar'] = 1                 # CSS flag
 
 # Let's do the conversion
 try:
@@ -29,7 +30,8 @@ try:
 	body, toc = txt2tags.convert(txt, config)
 	footer    = txt2tags.doFooter(config)
 	full_doc  = headers + toc + body + footer
-	print '\n'.join(full_doc)
+	finished  = txt2tags.finish_him(full_doc, config)
+	print '\n'.join(finished)
 
 # Txt2tags error, show the messsage to the user
 except txt2tags.error, msg:
