@@ -19,7 +19,7 @@ try:
 	# First we parse the text, spliting parts and getting config.
 	data = txt2tags.process_source_file(contents=txt)
 	# Then we convert it, dumping results to the 'tagged' list.
-	tagged, config = txt2tags.convert_this_files([data], dump_results=1)
+	tagged, config = txt2tags.convert_this_files([data])
 	# Show the tagged file on the screen.
 	print '\n'.join(tagged)
 
